<?php

namespace Drupal\tome_aws;

use Drupal\Core\Cache\CacheBackendInterface;
use Drupal\Core\DependencyInjection\DependencySerializationTrait;
use Drupal\tome_base\PathTrait;

/**
 * A service to cache remote content metadata.
 */
class RemoteContentMetadata {

  use PathTrait;
  use DependencySerializationTrait;

  /**
   * @var \Drupal\Core\Cache\CacheBackendInterface
   */
  protected $cacheTomeAwsRemoteMetadata;

  /**
   * @var \Drupal\tome_aws\AwsS3Client
   */
  protected $awsS3Client;

  /**
   * DeployBatch constructor.
   *
   * @param \Drupal\Core\Cache\CacheBackendInterface $cache_tome_aws_remote_metadata
   * @param \Drupal\tome_aws\AwsS3Client $aws_s3_client
   */
  public function __construct(CacheBackendInterface $cache_tome_aws_remote_metadata, AwsS3Client $aws_s3_client) {
    $this->cacheTomeAwsRemoteMetadata = $cache_tome_aws_remote_metadata;
    $this->awsS3Client = $aws_s3_client;
  }

  public function sync() {

    $this->cacheTomeAwsRemoteMetadata->invalidateAll();

    $results = $this->awsS3Client->getPaginator('ListObjects');
    foreach ($results as $result) {
      foreach ($result['Contents'] as $object) {
        if ($object['Size'] > 0) {
          $key  = $object['Key'];
          $etag = rtrim(ltrim($object['ETag'], '"'), '"');
          $this->cacheTomeAwsRemoteMetadata->set($key, $etag);
        }
      }
    }

  }

  public function get($cid) {
    return $this->cacheTomeAwsRemoteMetadata->get($cid);
  }

}
